@@ -89,7 +89,8 @@ class Fsdb(object):
                  pass_comments = 'y',
                  out_command_line = "____INTERNAL____",
                  write_nones_as_blanks = True,
-                 column_names=None):
+                 column_names=None,
+                 converters=None):
         """Returns a Fsdb class that can be used as an iterator.
 
            return_type can be pyfsdb.RETURN_AS_ARRAY (default) or
@@ -99,6 +100,9 @@ class Fsdb(object):
            If `pass_comments` is True and both an input and output file
            handle are available, any comments read in while reading
            are printed to the output.
+
+           `converters` may be passed in as an array or dict of
+           converters to call (such as int, float, etc)
         """
 
         self.return_type = return_type
@@ -108,6 +112,7 @@ class Fsdb(object):
         self._pass_comments = pass_comments
         self._write_nones_as_blanks = write_nones_as_blanks
         self._header_written = False
+        self._converters = converters
 
         if pass_comments not in ['y', 'n', 'e']:
             raise ValueError("pass_comments must be y/n/e")
@@ -134,18 +139,8 @@ class Fsdb(object):
     def file_handle(self, fileh):
         self.fileh = fileh
 
-        if not fileh:
-            return None
-
         return fileh
 
-        if self.return_type == RETURN_AS_DICTIONARY:
-            self.__next__ = self._next_as_dict
-        else:
-            self.__next__ = self._next_as_array
-
-        return self.fileh
-
     @property
     def headers(self):
         "Headers for the file handle being read."
@@ -383,6 +378,35 @@ class Fsdb(object):
 
         return header_line
 
+    @property
+    def converters(self):
+        """The list of conversion routines.
+
+        It may be an array, with a converter per column,
+        or a dict with a convert per named column.
+
+        This must be set before the file is opened/read.
+
+        Useful converted may include int, float, etc.
+        """
+        return self._converters
+
+    @converters.setter
+    def converters(self, new_converters):
+        self._converters = new_converters
+
+    def _convert_converters(self):
+        if isinstance(self._converters, dict):
+            converters = []
+            # convert this to an array based on column names
+            for column_name in self.column_names:
+                if column_name in self._converters and \
+                   callable(self._converters[column_name]):
+                    converters.append(self._converters[column_name])
+                else:
+                    converters.append(None)
+            self._converters = converters
+
     # column accessor helpers
     def get_column_number(self, column_name):
         "Given a column_name, returns its integer index into an array of values."
@@ -435,6 +459,8 @@ class Fsdb(object):
         if not self._header_line:
             self.read_header()
 
+        self._convert_converters()
+
         if self.return_type == RETURN_AS_DICTIONARY:
             self.__next__ = self._next_as_dict
         else:
@@ -462,6 +488,12 @@ class Fsdb(object):
                 self._comments.append(line)
         return next(self.fileh)
 
+    def _convert_array_values(self, row):
+        for (n, converter) in enumerate(self._converters):
+            if converter is not None and row[n] is not None:
+                row[n] = converter(row[n])
+        return row
+
     def _next_as_array(self):
         """Return the next object as an array of columns."""
 
@@ -475,6 +507,8 @@ class Fsdb(object):
         if len(self._current_row) < len(self._column_names):
             n = (len(self._column_names))-len(self._current_row)
             self._current_row.extend([''] * n)
+        if self._converters:
+            self._current_row = self._convert_array_values(self._current_row)
         return self._current_row
 
     def _next_as_dict(self):
@@ -654,10 +688,12 @@ class Fsdb(object):
             all_rows.append(row)
         return all_rows
 
-    def get_pandas(self, usecols=None, comment="#", data_has_comment_chars=False):
+    def get_pandas(self, usecols=None, comment="#",
+                   data_has_comment_chars=False, **kwargs):
         """Returns a pandas dataframe for the given data.  Warning: this
         cannot preserve comments in the files; FSDB comments are
-        stripped from the output.
+        stripped from the output.  Any other args will be passed to
+        pandas.read_csv()
         """
         import pandas
         column_names = self.column_names # forces opening and reading headers
@@ -680,7 +716,8 @@ class Fsdb(object):
             return df
         else:
             return pandas.read_csv(self.file_handle, sep='\t', comment=comment,
-                                   names=column_names, usecols=usecols)
+                                   names=column_names, usecols=usecols,
+                                   **kwargs)
 
     def put_pandas(self, df):
         "saves a pandas dataframe to the output file"
@@ -793,13 +830,3 @@ class Fsdb(object):
         self.close()
 
 
-def main():
-    print("at top")
-    fsdb = Fsdb()
-    line = sys.stdin.next()
-    result = fsdb.read_header(line)
-    print(result)
-
-
-if __name__ == "__main__":
-    main()
